@@ -7,6 +7,7 @@
 #include <osmium/handler/node_locations_for_ways.hpp>
 #include <osmium/index/map/all.hpp>
 #include <osmium/io/any_input.hpp>
+#include <osmium/io/file.hpp>
 #include <osmium/visitor.hpp>
 
 #include <boost/python.hpp>
@@ -58,21 +59,21 @@ void apply_with_area(osmium::io::Reader &r,
 
 
 protected:
-void apply(const std::string &filename, osmium::osm_entity_bits::type types,
+void apply(const osmium::io::File &file, osmium::osm_entity_bits::type types,
            pre_handler pre = no_handler,
            const std::string &idx = "sparse_mem_array") {
 
     switch (pre) {
     case no_handler:
         {
-            osmium::io::Reader reader(filename, types);
+            osmium::io::Reader reader(file, types);
             osmium::apply(reader, *this);
             reader.close();
             break;
         }
     case location_handler:
         {
-            osmium::io::Reader reader(filename, types);
+            osmium::io::Reader reader(file, types);
             apply_with_location(reader, idx);
             reader.close();
             break;
@@ -82,11 +83,11 @@ void apply(const std::string &filename, osmium::osm_entity_bits::type types,
             osmium::area::Assembler::config_type assembler_config;
             osmium::area::MultipolygonCollector<osmium::area::Assembler> collector(assembler_config);
 
-            osmium::io::Reader reader1(filename);
+            osmium::io::Reader reader1(file);
             collector.read_relations(reader1);
             reader1.close();
 
-            osmium::io::Reader reader2(filename);
+            osmium::io::Reader reader2(file);
             apply_with_area(reader2, collector, idx);
             reader2.close();
             break;
@@ -144,6 +145,25 @@ struct SimpleHandlerWrap: BaseHandler, wrapper<BaseHandler> {
 
     void apply_file(const std::string &filename, bool locations = false,
                     const std::string &idx = "sparse_mem_array")
+    {
+        apply_object(osmium::io::File(filename), locations, idx);
+    }
+
+    void apply_buffer(const boost::python::object &buf, const boost::python::str &format,
+                      bool locations = false,
+                      const std::string &idx = "sparse_mem_array")
+    {
+        Py_buffer pybuf;
+        PyObject_GetBuffer(buf.ptr(), &pybuf, PyBUF_C_CONTIGUOUS);
+        size_t len = pybuf.len;
+        const char *cbuf = reinterpret_cast<const char *>(pybuf.buf);
+        const char *cfmt = boost::python::extract<const char *>(format);
+
+        apply_object(osmium::io::File(cbuf, len, cfmt), locations, idx);
+    }
+
+private:
+    void apply_object(osmium::io::File file, bool locations, const std::string &idx)
     {
         osmium::osm_entity_bits::type entities = osmium::osm_entity_bits::nothing;
         BaseHandler::pre_handler handler = locations?
@@ -166,7 +186,7 @@ struct SimpleHandlerWrap: BaseHandler, wrapper<BaseHandler> {
         if (this->get_override("changeset"))
             entities |= osmium::osm_entity_bits::changeset;
 
-        apply(filename, entities, handler, idx);
+        apply(file, entities, handler, idx);
     }
 };
 
